@@ -4,10 +4,10 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose_a_directory choose_a_file choose_directories choose_a_number choose_a_subset settings_menu
-                     insert_sep get_term_size get_term_width unicode_sprintf
+                     insert_sep get_term_size get_term_width get_term_height unicode_sprintf
                      choose_a_dir choose_dirs ); # 21.09.2019    # after transition -> remove
 
 use Carp                  qw( croak );
@@ -880,11 +880,20 @@ sub get_term_width {
     return $term_width;
 }
 
+sub get_term_height {
+    require Term::Choose::Screen;
+    my $term_height = ( Term::Choose::Screen::get_term_size() )[1];
+    return $term_height;
+}
+
 
 sub unicode_sprintf {
-    #my ( $unicode, $avail_width, $right_justify ) = @_;
+    #my ( $unicode, $avail_width, $right_justify, $add_dots ) = @_;
     my $colwidth = print_columns( $_[0] );
     if ( $colwidth > $_[1] ) {
+        if ( $_[3] ) {
+            return cut_to_printwidth( $_[0], $_[1] - 3 ) . '...';
+        }
         return cut_to_printwidth( $_[0], $_[1] );
     }
     elsif ( $colwidth < $_[1] ) {
@@ -920,7 +929,7 @@ Term::Choose::Util - TUI-related functions for selecting directories, files, num
 
 =head1 VERSION
 
-Version 0.102
+Version 0.103
 
 =cut
 
